@@ -10,6 +10,7 @@ from abc import ABC, abstractmethod
 import numpy as np
 import requests
 from bs4 import BeautifulSoup
+import nsetools
 
 nifty_next_50 = ["ABBOTINDIA", "ACC", "ADANIENT", "ADANIGREEN", "ADANITRANS", "ALKEM", "AMBUJACEM", "APOLLOHOSP", "AUROPHARMA", "DMART", "BAJAJHLDNG", "BANDHANBNK", "BERGEPAINT", "BIOCON", "BOSCHLTD", "CADILAHC", "COLPAL", "DABUR", "DLF", "GAIL", "GODREJCP", "HAVELLS", "HDFCAMC", "HINDPETRO", "ICICIGI", "ICICIPRULI", "IGL", "NAUKRI", "INDIGO", "JUBLFOOD", "LTI", "LUPIN", "MARICO", "MOTHERSUMI", "MRF", "MUTHOOTFIN", "NMDC", "PETRONET", "PIDILITIND", "PEL", "PGHH", "PNB", "SBICARD", "SIEMENS", "TORNTPHARM", "UBL", "MCDOWELL-N", "VEDL", "YESBANK"]
 
@@ -298,6 +299,7 @@ class OptionIVDiffStrategy(Strategy):
     
     file_path = '{0}_OptionIVDiffStrategy.json'.format(datetime.today().strftime("%Y%m%d"))
     helper = OptionHelper()
+    lot_sizes = nsetools.Nse().get_fno_lot_sizes()
     
     def getTickerList(self, pending = False, processed = False):
 
@@ -341,11 +343,18 @@ class OptionIVDiffStrategy(Strategy):
         strike_low_put_nxt_price = df[df['strikePrice'].isin([strike_low_nxt])].put_price.values[0]
         strike_high_call_price = df[df['strikePrice'].isin([strike_high])].call_price.values[0]
         strike_high_call_nxt_price = df[df['strikePrice'].isin([strike_high_nxt])].call_price.values[0]
+        lot_size = self.lot_sizes.get(ticker, 1)
+        strike_low_max_profit = (strike_low_put_price - strike_low_put_nxt_price)*lot_size
+        strike_low_max_loss = (strike_low_nxt - strike_low)*lot_size + strike_low_max_profit
+        strike_high_max_profit = (strike_high_call_price - strike_high_call_nxt_price)*lot_size
+        strike_high_max_loss = (strike_high_nxt - strike_high)*lot_size + strike_high_max_profit
+        
         data = {
             'ticker' : ticker,
             'iv_ce' : iv_ce,
             'iv_pe' : iv_pe,
             'underlying' : float(up),
+            'lot_size' : float(lot_size),
             'days_to_expiry' : days_to_expiry,
             'iv' : iv,
             'low' : low,
@@ -358,8 +367,14 @@ class OptionIVDiffStrategy(Strategy):
             'strike_low_nxt' : float(strike_low_nxt),
             'strike_high_nxt' : float(strike_high_nxt),
             'strike_low_pe_nxt_price' : strike_low_put_nxt_price,
-            'strike_high_ce_nxt_price' : strike_high_call_nxt_price
+            'strike_high_ce_nxt_price' : strike_high_call_nxt_price,
+            'strike_low_max_profit' : strike_low_max_profit,
+            'strike_low_max_loss' : strike_low_max_loss,
+            'strike_high_max_profit' : strike_high_max_profit,
+            'strike_high_max_loss' : strike_high_max_loss
             }
+        data['strategy_action'], data['strategy_max_profit'], data['strategy_max_loss'] = self._getAction(data)
+        data['strategy_summary'] = self._strategySummary(data)
         return data
     
     def screener(self,nextExpiryCount = 1):
@@ -396,7 +411,6 @@ class OptionIVDiffStrategy(Strategy):
             result = self.saved_data.get('result', [])
             
         data = pd.DataFrame(result)
-        data['Action'] = data.apply(lambda x: self._getAction(x), axis = 1)
         return data
     
     
@@ -407,9 +421,36 @@ class OptionIVDiffStrategy(Strategy):
         strikes.sort(key = lambda x: self._sortStrikes(value, x))
         filtered_strikes = strikes[:count]
         return filtered_strikes
-
+    
     def _getAction(self, x, threshold = 10):
-        action = ''
+        
+        action = ('', 0, 0) # (action, max_profit, max_loss)
+        if abs(x['iv_diff']) >= threshold:
+            if x['iv_diff'] > 0:
+                action = ('Sell PUT', x['strike_low_max_profit'], x['strike_low_max_loss'])
+            else:
+                action = ('Sell CALL', x['strike_high_max_profit'], x['strike_high_max_loss'])
+        return action
+
+    def _strategySummary(self, x):
+        message = ''
+        if x['strategy_action'] == 'Sell PUT':
+            message += '<b>' + x['ticker'] + '</b>\n\n'
+            message += '<b>Trades:</b>\n' + 'Sell PUT@' + str(x['strike_low']) + ' for ' + str(x['strike_low_pe_price']) +'\n'
+            message += 'Buy PUT@' + str(x['strike_low_nxt']) + ' for ' + str(x['strike_low_pe_nxt_price']) +'\n'
+            message += '<b>Max Profit:</b> ' + str(x['strategy_max_profit']) + '\n'
+            message += '<b>Max Loss:</b> ' + str(x['strategy_max_loss']) + '\n'
+        elif x['strategy_action'] == 'Sell CALL':
+            message += '<b>' + x['ticker'] + '</b>\n\n'
+            message += '<b>Trades:</b>\n' + 'Sell CALL@' + str(x['strike_high']) + ' for ' + str(x['strike_high_ce_price']) +'\n'
+            message += 'Buy CALL@' + str(x['strike_high_nxt']) + ' for ' + str(x['strike_high_ce_nxt_price']) +'\n'
+            message += '<b>Max Profit:</b> ' + str(x['strategy_max_profit']) + '\n'
+            message += '<b>Max Loss:</b> ' + str(x['strategy_max_loss']) + '\n'
+        else:
+            pass
+        
+        return message
+    
         if abs(x['iv_diff']) >= threshold:
             if x['iv_diff'] > 0:
                 action = 'Sell ' + x['ticker'] + ' PUT@' + str(x['strike_low']) + ' for ' + str(x['strike_low_pe_price'])
